# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: make87_messages/detection/box/boxes_2d.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'make87_messages/detection/box/boxes_2d.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.detection.box import box_2d_pb2 as make87__messages_dot_detection_dot_box_dot_box__2d__pb2
from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,make87_messages/detection/box/boxes_2d.proto\x12\x1dmake87_messages.detection.box\x1a*make87_messages/detection/box/box_2d.proto\x1a!make87_messages/core/header.proto\"l\n\x07\x42oxes2D\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x33\n\x05\x62oxes\x18\x02 \x03(\x0b\x32$.make87_messages.detection.box.Box2D\"\x82\x01\n\x12\x42oxes2DAxisAligned\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12>\n\x05\x62oxes\x18\x02 \x03(\x0b\x32/.make87_messages.detection.box.Box2DAxisAlignedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.detection.box.boxes_2d_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BOXES2D']._serialized_start=158
  _globals['_BOXES2D']._serialized_end=266
  _globals['_BOXES2DAXISALIGNED']._serialized_start=269
  _globals['_BOXES2DAXISALIGNED']._serialized_end=399
# @@protoc_insertion_point(module_scope)
